import React from 'react';
import { DateRange, DayClickEventHandler, DayPickerProps, DayPickerRangeProps, Modifiers } from '../../types';
/** Represent the modifiers that are changed by the range selection. */
export declare type SelectRangeModifiers = Pick<Modifiers, 'selected' | 'range_start' | 'range_end' | 'range_middle' | 'disabled'>;
/** Represents the value of a [[SelectRangeContext]]. */
export interface SelectRangeContextValue {
    /** The range of days that has been selected. */
    selected: DateRange | undefined;
    /** The modifiers for the corresponding selection. */
    modifiers: SelectRangeModifiers;
    /** Event handler to attach to the day button to enable the range select. */
    onDayClick?: DayClickEventHandler;
}
/**
 * The SelectRange context shares details about the selected days when in
 * range selection mode.
 *
 * Access this context from the [[useSelectRange]] hook.
 */
export declare const SelectRangeContext: React.Context<SelectRangeContextValue | undefined>;
declare type SelectRangeProviderProps = {
    initialProps: DayPickerProps;
    children: React.ReactNode;
};
/** Provides the values for the [[SelectRangeProvider]]. */
export declare function SelectRangeProvider(props: SelectRangeProviderProps): JSX.Element;
declare type SelectRangeProviderInternalProps = {
    initialProps: DayPickerRangeProps;
    children: React.ReactNode;
};
export declare function SelectRangeProviderInternal({ initialProps, children }: SelectRangeProviderInternalProps): JSX.Element;
export {};
